@@ -832,7 +832,7 @@ class BottomThickSolver:
 
 
         # Расчёт дна на срезание
-        h3_sh = poc * r1 / sigma_dt
+        # h3_sh = poc * r1 / sigma_dt
 
         # Прогиб посередине дна снаряда
         Ef = p_data['Ef']
@@ -841,9 +841,9 @@ class BottomThickSolver:
         # Критическое давление
         pkr = 2.42 * sigma_dt * (hd / r1)**2
 
-        results = {'hd': hd, 'h1_sh': h1_sh, 'h3_sh': h3_sh, 'f': f, 'pkr': pkr, 'poc': poc, 'p_sd': p_sd, 'qd': qd,
+        results = {'hd': hd, 'h1_sh': h1_sh, 'h2_sh': h2_sh, 'f': f, 'pkr': pkr, 'poc': poc, 'p_sd': p_sd, 'qd': qd,
                    'K': K}
-        results['h2_sh'] = h2_sh
+
 
         state[BottomThickSolver.name] = results
 
@@ -933,12 +933,12 @@ class RampCorpSolver:
     # Определяем координаты для каждого сечения
     def run(self, data: dict, state: dict):
         p_data = self.preprocessed_data
-
+        status = 'не определено'
         # параметры для расчёта
         r5 = p_data['res_press_mass']['r'][5]
         R5 = p_data['res_press_mass']['R'][5]
         Pm = p_data['Pmax']
-        Pc_5 = p_data['res_stress']['Pc_sh'][5]
+        Pcd_5 = p_data['res_stress']['Pc_sh'][5]
         sigma_tsh = p_data['sigma_tsh']
         lambd = p_data['lambd']
         eps_sh = p_data['eps_sh']
@@ -950,9 +950,9 @@ class RampCorpSolver:
         Prasch = 1.1 * Pm
 
         # Расчёт действительного радиального давления
-        q_oc = np.abs(sigma_x5) / sigma_tsh - (Prasch - Pc_5 * ro_5 ** 2) / (sigma_tsh * (1 - ro_5 ** 2))
+        q_oc = np.abs(sigma_x5) / sigma_tsh - (Prasch - Pcd_5 * ro_5 ** 2) / (sigma_tsh * (1 - ro_5 ** 2))
 
-        P_rad = ((Prasch - Pc_5) * np.sqrt(3)) / (sigma_tsh * (1 - ro_5 ** 2))
+        P_rad = ((Prasch - Pcd_5) * np.sqrt(3)) / (sigma_tsh * (1 - ro_5 ** 2))
         u = ((1 - ro_5 ** 2) / (2 * ro_5 ** 2 * abs(q_oc))) * np.sqrt(
             (((1 + ro_5 ** 2) / (1 - ro_5 ** 2)) ** 2 - q_oc ** 2) * (1 - q_oc ** 2))
 
@@ -965,44 +965,52 @@ class RampCorpSolver:
                 np.abs(q_oc) / (ro_5 ** 2 * u)) - Pkr1
         Pkr2 = Pkr1 + deltaPkr1 * (1 - lambd)
 
+        # Третье критическое давление
+        x_5 = l
+        Pkr3 = 24.6 * ((1 - lambd) / (eps_sh * (1 + np.sqrt(1 - lambd)) ** 2)) * ((1 - ro_5) ** 2 / (1 + ro_5) ** 4) * \
+               (1 + 3.4 * ((R5 + r5) / x_5) ** 4)
+
+
         # Прогиб наружней поверхности корпуса снаряда
         k = -1 * (q_oc / q_oc)  # меняем знак для последнего множителя формул
         # Если мы в упругой зоне, считаем упругий прогиб
         if P_rad < Pkr1:
-            Wh5_sh = (np.sqrt(3) / 2) * eps_sh * r5 * (P_rad - (q_oc / (ro_5 * np.sqrt(3))))
+            Wh_sh = (np.sqrt(3) / 2) * eps_sh * r5 * (P_rad - (q_oc / (ro_5 * np.sqrt(3))))
+            status = 'материал в упругой зоне'
         # Если мы в сложно-напряженном состоянии
         elif Pkr1 <= P_rad < Pkr2:
-            Wh5_sh = (np.sqrt(3) / 2) * eps_sh * r5 * (1 / np.sqrt(1 + u ** 2 * ro_5 ** 4)) * (
+            Wh_sh = (np.sqrt(3) / 2) * eps_sh * r5 * (1 / np.sqrt(1 + u ** 2 * ro_5 ** 4)) * (
                         u + k * (1 / (ro_5 * np.sqrt(3))))
+            status = 'материал в упруго-пластической зоне'
         # Если мы в пластической зоне
-        else:
-            Wh5_sh = (np.sqrt(3) / 2) * eps_sh * r5 * (1 / (np.sqrt(1 + u ** 2 * ro_5 ** 4)) +
+        elif Pkr2 <= P_rad < Pkr3:
+            Wh_sh = (np.sqrt(3) / 2) * eps_sh * r5 * (1 / (np.sqrt(1 + u ** 2 * ro_5 ** 4)) +
                                                        ((u * ro_5 ** 2) / (1 + ro_5 ** 2 * u ** 2)) * (
                                                                    (P_rad - Pkr2) / (1 - lambd))) * (
                                  u + k * (1 / (ro_5 * np.sqrt(3))))
+            status = 'материал в пластической зоне'
 
-            # Влияние близости дна
+        # Влияние близости дна
         a_5 = (R5 + r5) / 2
         h_5 = R5 - r5
         Y_5 = 0.5 * (np.sqrt(3) / np.sqrt(2)) * (l / np.sqrt(a_5 * h_5))
         k_s = 1 - (np.cos(Y_5) + np.sin(Y_5)) * np.exp(-Y_5)
 
         # Прогиб стенки корпуса снаряда
-        WH5 = k_s * Wh5_sh
+        WH = k_s * Wh_sh
 
         # Прогиб срединной поверхности
-        W5 = WH5 * (1 + h_5 / (2 * a_5))
+        W_sr = WH * (1 + h_5 / (2 * a_5))
+
+        # Остаточный прогиб срединной поверхности
+        WH_sh_elc = (np.sqrt(3) / 2) * eps_sh * r5 * (P_rad - (q_oc / (ro_5 * np.sqrt(3)))) # упругая состовляющая
+        WH_zv = WH - WH_sh_elc * k_s # отнимаем из общего прогиба упругую составляющую с учётом близости дна
+
 
-        # Третье критическое давление
-        x_5 = l
-        Pkr3 = 24.6 * ((1 - lambd) / (eps_sh * (1 + np.sqrt(1 - lambd)) ** 2)) * ((1 - ro_5) ** 2 / (1 + ro_5) ** 4) * \
-               (1 + 3.4 * ((R5 + r5) / x_5) ** 4)
 
         # Допустимое значение прогиба (РАССЧИТЫВАЕТСЯ В 7 ЛР!!!)
-
-
-        results = {'P_rad': P_rad, 'Pkr1': Pkr1, 'Pkr2': Pkr2, 'Pkr3': Pkr3, 'W5': W5, 'WH5': WH5, 'q_oc': q_oc,
-                   'k_s': k_s, 'l': l, 'Wh5_sh': Wh5_sh}
+        results = {'P_rad': P_rad, 'Pkr1': Pkr1, 'Pkr2': Pkr2, 'Pkr3': Pkr3, 'W5': W_sr, 'WH5': WH, 'WH5_ost': WH_zv,
+                   'q_oc': q_oc, 'k_s': k_s, 'l': l, 'status': status}
 
         state[RampCorpSolver.name] = results
 
